pub struct EnvoyMagicBackupEnabled;Trait Implementations
Sourceimpl Archive for EnvoyMagicBackupEnabled
impl Archive for EnvoyMagicBackupEnabled
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedEnvoyMagicBackupEnabled
type Archived = ArchivedEnvoyMagicBackupEnabled
The archived representation of this type. Read more
Sourcetype Resolver = EnvoyMagicBackupEnabledResolver
type Resolver = EnvoyMagicBackupEnabledResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for EnvoyMagicBackupEnabled
impl Clone for EnvoyMagicBackupEnabled
Sourcefn clone(&self) -> EnvoyMagicBackupEnabled
fn clone(&self) -> EnvoyMagicBackupEnabled
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvoyMagicBackupEnabled
impl Debug for EnvoyMagicBackupEnabled
Sourceimpl<__D: Fallible + ?Sized> Deserialize<EnvoyMagicBackupEnabled, __D> for Archived<EnvoyMagicBackupEnabled>
impl<__D: Fallible + ?Sized> Deserialize<EnvoyMagicBackupEnabled, __D> for Archived<EnvoyMagicBackupEnabled>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<EnvoyMagicBackupEnabled, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<EnvoyMagicBackupEnabled, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for EnvoyMagicBackupEnabled
impl MessageId for EnvoyMagicBackupEnabled