pub struct GetXidDocument;Trait Implementations
Sourceimpl Archive for GetXidDocument
impl Archive for GetXidDocument
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetXidDocument
type Archived = ArchivedGetXidDocument
The archived representation of this type. Read more
Sourcetype Resolver = GetXidDocumentResolver
type Resolver = GetXidDocumentResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetXidDocument
impl BlockingArchive for GetXidDocument
Sourceimpl Debug for GetXidDocument
impl Debug for GetXidDocument
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetXidDocument, __D> for Archived<GetXidDocument>
impl<__D: Fallible + ?Sized> Deserialize<GetXidDocument, __D> for Archived<GetXidDocument>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetXidDocument, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetXidDocument, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetXidDocument
impl MessageId for GetXidDocument