pub struct NotifyOnboardingState {
pub state: OnboardingState,
}Fields
state: OnboardingStateTrait Implementations
Sourceimpl Archive for NotifyOnboardingStatewhere
OnboardingState: Archive,
impl Archive for NotifyOnboardingStatewhere
OnboardingState: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedNotifyOnboardingState
type Archived = ArchivedNotifyOnboardingState
The archived representation of this type. Read more
Sourcetype Resolver = NotifyOnboardingStateResolver
type Resolver = NotifyOnboardingStateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for NotifyOnboardingState
impl Debug for NotifyOnboardingState
Sourceimpl<__D: Fallible + ?Sized> Deserialize<NotifyOnboardingState, __D> for Archived<NotifyOnboardingState>where
OnboardingState: Archive,
<OnboardingState as Archive>::Archived: Deserialize<OnboardingState, __D>,
impl<__D: Fallible + ?Sized> Deserialize<NotifyOnboardingState, __D> for Archived<NotifyOnboardingState>where
OnboardingState: Archive,
<OnboardingState as Archive>::Archived: Deserialize<OnboardingState, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<NotifyOnboardingState, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<NotifyOnboardingState, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for NotifyOnboardingState
impl MessageId for NotifyOnboardingState
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for NotifyOnboardingStatewhere
OnboardingState: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for NotifyOnboardingStatewhere
OnboardingState: Serialize<__S>,