pub struct RestoreShard {
pub seed_fingerprint: SeedFingerprint,
pub timestamp: u32,
}Fields
seed_fingerprint: SeedFingerprinttimestamp: u32Trait Implementations
Sourceimpl Archive for RestoreShardwhere
SeedFingerprint: Archive,
u32: Archive,
impl Archive for RestoreShardwhere
SeedFingerprint: Archive,
u32: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRestoreShard
type Archived = ArchivedRestoreShard
The archived representation of this type. Read more
Sourcetype Resolver = RestoreShardResolver
type Resolver = RestoreShardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for RestoreShard
impl BlockingArchive for RestoreShard
Sourcetype Response = Result<RestoreShardResponse, SendMessageError>
type Response = Result<RestoreShardResponse, SendMessageError>
response type for this message
Sourceimpl Debug for RestoreShard
impl Debug for RestoreShard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RestoreShard, __D> for Archived<RestoreShard>
impl<__D: Fallible + ?Sized> Deserialize<RestoreShard, __D> for Archived<RestoreShard>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RestoreShard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RestoreShard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RestoreShard
impl MessageId for RestoreShard
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RestoreShardwhere
SeedFingerprint: Serialize<__S>,
u32: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RestoreShardwhere
SeedFingerprint: Serialize<__S>,
u32: Serialize<__S>,