pub struct SendAccountUpdate {
pub account_id: String,
pub update: Vec<u8>,
}Fields
account_id: Stringupdate: Vec<u8>Trait Implementations
Sourceimpl Archive for SendAccountUpdatewhere
String: Archive,
Vec<u8>: Archive,
impl Archive for SendAccountUpdatewhere
String: Archive,
Vec<u8>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSendAccountUpdate
type Archived = ArchivedSendAccountUpdate
The archived representation of this type. Read more
Sourcetype Resolver = SendAccountUpdateResolver
type Resolver = SendAccountUpdateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SendAccountUpdate
impl BlockingArchive for SendAccountUpdate
Sourcetype Response = Result<(), SendMessageError>
type Response = Result<(), SendMessageError>
response type for this message
Sourceimpl Clone for SendAccountUpdate
impl Clone for SendAccountUpdate
Sourcefn clone(&self) -> SendAccountUpdate
fn clone(&self) -> SendAccountUpdate
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendAccountUpdate
impl Debug for SendAccountUpdate
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SendAccountUpdate, __D> for Archived<SendAccountUpdate>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SendAccountUpdate, __D> for Archived<SendAccountUpdate>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SendAccountUpdate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SendAccountUpdate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SendAccountUpdate
impl MessageId for SendAccountUpdate
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SendAccountUpdatewhere
String: Serialize<__S>,
Vec<u8>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SendAccountUpdatewhere
String: Serialize<__S>,
Vec<u8>: Serialize<__S>,