pub struct SendApplyPassphrase {
pub fingerprint: Option<String>,
}Fields
fingerprint: Option<String>Trait Implementations
Sourceimpl Archive for SendApplyPassphrase
impl Archive for SendApplyPassphrase
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSendApplyPassphrase
type Archived = ArchivedSendApplyPassphrase
The archived representation of this type. Read more
Sourcetype Resolver = SendApplyPassphraseResolver
type Resolver = SendApplyPassphraseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for SendApplyPassphrase
impl Clone for SendApplyPassphrase
Sourcefn clone(&self) -> SendApplyPassphrase
fn clone(&self) -> SendApplyPassphrase
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendApplyPassphrase
impl Debug for SendApplyPassphrase
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SendApplyPassphrase, __D> for Archived<SendApplyPassphrase>
impl<__D: Fallible + ?Sized> Deserialize<SendApplyPassphrase, __D> for Archived<SendApplyPassphrase>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SendApplyPassphrase, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SendApplyPassphrase, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SendApplyPassphrase
impl MessageId for SendApplyPassphrase
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SendApplyPassphrase
impl<__S: Fallible + ?Sized> Serialize<__S> for SendApplyPassphrase