pub struct SendPrimeFiatPreference {
pub currency_code: String,
}Fields
currency_code: StringTrait Implementations
Sourceimpl Archive for SendPrimeFiatPreferencewhere
String: Archive,
impl Archive for SendPrimeFiatPreferencewhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSendPrimeFiatPreference
type Archived = ArchivedSendPrimeFiatPreference
The archived representation of this type. Read more
Sourcetype Resolver = SendPrimeFiatPreferenceResolver
type Resolver = SendPrimeFiatPreferenceResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for SendPrimeFiatPreference
impl Clone for SendPrimeFiatPreference
Sourcefn clone(&self) -> SendPrimeFiatPreference
fn clone(&self) -> SendPrimeFiatPreference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendPrimeFiatPreference
impl Debug for SendPrimeFiatPreference
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SendPrimeFiatPreference, __D> for Archived<SendPrimeFiatPreference>
impl<__D: Fallible + ?Sized> Deserialize<SendPrimeFiatPreference, __D> for Archived<SendPrimeFiatPreference>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SendPrimeFiatPreference, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SendPrimeFiatPreference, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SendPrimeFiatPreference
impl MessageId for SendPrimeFiatPreference
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SendPrimeFiatPreferencewhere
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SendPrimeFiatPreferencewhere
String: Serialize<__S>,