pub struct SendRestoreMagicBackupResult {
pub result: RestoreMagicBackupResult,
}Fields
result: RestoreMagicBackupResultTrait Implementations
Sourceimpl Archive for SendRestoreMagicBackupResultwhere
RestoreMagicBackupResult: Archive,
impl Archive for SendRestoreMagicBackupResultwhere
RestoreMagicBackupResult: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSendRestoreMagicBackupResult
type Archived = ArchivedSendRestoreMagicBackupResult
The archived representation of this type. Read more
Sourcetype Resolver = SendRestoreMagicBackupResultResolver
type Resolver = SendRestoreMagicBackupResultResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for SendRestoreMagicBackupResult
impl Clone for SendRestoreMagicBackupResult
Sourcefn clone(&self) -> SendRestoreMagicBackupResult
fn clone(&self) -> SendRestoreMagicBackupResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendRestoreMagicBackupResult
impl Debug for SendRestoreMagicBackupResult
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SendRestoreMagicBackupResult, __D> for Archived<SendRestoreMagicBackupResult>where
RestoreMagicBackupResult: Archive,
<RestoreMagicBackupResult as Archive>::Archived: Deserialize<RestoreMagicBackupResult, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SendRestoreMagicBackupResult, __D> for Archived<SendRestoreMagicBackupResult>where
RestoreMagicBackupResult: Archive,
<RestoreMagicBackupResult as Archive>::Archived: Deserialize<RestoreMagicBackupResult, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SendRestoreMagicBackupResult, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SendRestoreMagicBackupResult, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SendRestoreMagicBackupResultwhere
RestoreMagicBackupResult: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SendRestoreMagicBackupResultwhere
RestoreMagicBackupResult: Serialize<__S>,