pub struct StartFirmwareUpdate {
pub chunk_offset: Option<u64>,
}Fields
chunk_offset: Option<u64>Trait Implementations
Sourceimpl Archive for StartFirmwareUpdatewhere
Option<u64>: Archive,
impl Archive for StartFirmwareUpdatewhere
Option<u64>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedStartFirmwareUpdate
type Archived = ArchivedStartFirmwareUpdate
The archived representation of this type. Read more
Sourcetype Resolver = StartFirmwareUpdateResolver
type Resolver = StartFirmwareUpdateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for StartFirmwareUpdate
impl BlockingArchive for StartFirmwareUpdate
Sourcetype Response = Result<(), SendMessageError>
type Response = Result<(), SendMessageError>
response type for this message
Sourceimpl Clone for StartFirmwareUpdate
impl Clone for StartFirmwareUpdate
Sourcefn clone(&self) -> StartFirmwareUpdate
fn clone(&self) -> StartFirmwareUpdate
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartFirmwareUpdate
impl Debug for StartFirmwareUpdate
Sourceimpl<__D: Fallible + ?Sized> Deserialize<StartFirmwareUpdate, __D> for Archived<StartFirmwareUpdate>where
Option<u64>: Archive,
<Option<u64> as Archive>::Archived: Deserialize<Option<u64>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<StartFirmwareUpdate, __D> for Archived<StartFirmwareUpdate>where
Option<u64>: Archive,
<Option<u64> as Archive>::Archived: Deserialize<Option<u64>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<StartFirmwareUpdate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<StartFirmwareUpdate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for StartFirmwareUpdate
impl MessageId for StartFirmwareUpdate
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for StartFirmwareUpdatewhere
Option<u64>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for StartFirmwareUpdatewhere
Option<u64>: Serialize<__S>,