pub struct StartRestoreMagicBackup;Trait Implementations
Sourceimpl Archive for StartRestoreMagicBackup
impl Archive for StartRestoreMagicBackup
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedStartRestoreMagicBackup
type Archived = ArchivedStartRestoreMagicBackup
The archived representation of this type. Read more
Sourcetype Resolver = StartRestoreMagicBackupResolver
type Resolver = StartRestoreMagicBackupResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for StartRestoreMagicBackup
impl Clone for StartRestoreMagicBackup
Sourcefn clone(&self) -> StartRestoreMagicBackup
fn clone(&self) -> StartRestoreMagicBackup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartRestoreMagicBackup
impl Debug for StartRestoreMagicBackup
Sourceimpl<__D: Fallible + ?Sized> Deserialize<StartRestoreMagicBackup, __D> for Archived<StartRestoreMagicBackup>
impl<__D: Fallible + ?Sized> Deserialize<StartRestoreMagicBackup, __D> for Archived<StartRestoreMagicBackup>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<StartRestoreMagicBackup, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<StartRestoreMagicBackup, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for StartRestoreMagicBackup
impl MessageId for StartRestoreMagicBackup