pub struct SubscribeRestoreMagicBackup;Trait Implementations
Sourceimpl Archive for SubscribeRestoreMagicBackup
impl Archive for SubscribeRestoreMagicBackup
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeRestoreMagicBackup
type Archived = ArchivedSubscribeRestoreMagicBackup
The archived representation of this type. Read more
Sourcetype Resolver = SubscribeRestoreMagicBackupResolver
type Resolver = SubscribeRestoreMagicBackupResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SubscribeRestoreMagicBackup
impl Debug for SubscribeRestoreMagicBackup
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeRestoreMagicBackup, __D> for Archived<SubscribeRestoreMagicBackup>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeRestoreMagicBackup, __D> for Archived<SubscribeRestoreMagicBackup>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeRestoreMagicBackup, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeRestoreMagicBackup, <__D as Fallible>::Error>
Deserializes using the given deserializer