pub struct SubscribeSecurityCheckState;Trait Implementations
Sourceimpl Archive for SubscribeSecurityCheckState
impl Archive for SubscribeSecurityCheckState
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeSecurityCheckState
type Archived = ArchivedSubscribeSecurityCheckState
The archived representation of this type. Read more
Sourcetype Resolver = SubscribeSecurityCheckStateResolver
type Resolver = SubscribeSecurityCheckStateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl ArchiveSubscription for SubscribeSecurityCheckState
impl ArchiveSubscription for SubscribeSecurityCheckState
type Event = SecurityCheckState
type Error = Infallible
Sourceimpl Debug for SubscribeSecurityCheckState
impl Debug for SubscribeSecurityCheckState
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeSecurityCheckState, __D> for Archived<SubscribeSecurityCheckState>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeSecurityCheckState, __D> for Archived<SubscribeSecurityCheckState>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeSecurityCheckState, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeSecurityCheckState, <__D as Fallible>::Error>
Deserializes using the given deserializer