pub struct PublishPsbt {
pub transaction: BroadcastTransaction,
}Fields
transaction: BroadcastTransactionTrait Implementations
Sourceimpl Archive for PublishPsbtwhere
BroadcastTransaction: Archive,
impl Archive for PublishPsbtwhere
BroadcastTransaction: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPublishPsbt
type Archived = ArchivedPublishPsbt
The archived representation of this type. Read more
Sourcetype Resolver = PublishPsbtResolver
type Resolver = PublishPsbtResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for PublishPsbt
impl BlockingArchive for PublishPsbt
Sourcetype Response = Result<(), SendMessageError>
type Response = Result<(), SendMessageError>
response type for this message
Sourceimpl Clone for PublishPsbt
impl Clone for PublishPsbt
Sourcefn clone(&self) -> PublishPsbt
fn clone(&self) -> PublishPsbt
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublishPsbt
impl Debug for PublishPsbt
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PublishPsbt, __D> for Archived<PublishPsbt>where
BroadcastTransaction: Archive,
<BroadcastTransaction as Archive>::Archived: Deserialize<BroadcastTransaction, __D>,
impl<__D: Fallible + ?Sized> Deserialize<PublishPsbt, __D> for Archived<PublishPsbt>where
BroadcastTransaction: Archive,
<BroadcastTransaction as Archive>::Archived: Deserialize<BroadcastTransaction, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PublishPsbt, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PublishPsbt, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for PublishPsbt
impl MessageId for PublishPsbt
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for PublishPsbtwhere
BroadcastTransaction: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for PublishPsbtwhere
BroadcastTransaction: Serialize<__S>,