pub struct SendApplyPassphrase {
pub fingerprint: Option<String>,
}Fields
fingerprint: Option<String>Trait Implementations
Sourceimpl Archive for SendApplyPassphrasewhere
Option<String>: Archive,
impl Archive for SendApplyPassphrasewhere
Option<String>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSendApplyPassphrase
type Archived = ArchivedSendApplyPassphrase
The archived representation of this type. Read more
Sourcetype Resolver = SendApplyPassphraseResolver
type Resolver = SendApplyPassphraseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SendApplyPassphrase
impl BlockingArchive for SendApplyPassphrase
Sourcetype Response = Result<(), SendMessageError>
type Response = Result<(), SendMessageError>
response type for this message
Sourceimpl Clone for SendApplyPassphrase
impl Clone for SendApplyPassphrase
Sourcefn clone(&self) -> SendApplyPassphrase
fn clone(&self) -> SendApplyPassphrase
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendApplyPassphrase
impl Debug for SendApplyPassphrase
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SendApplyPassphrase, __D> for Archived<SendApplyPassphrase>where
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SendApplyPassphrase, __D> for Archived<SendApplyPassphrase>where
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SendApplyPassphrase, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SendApplyPassphrase, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SendApplyPassphrase
impl MessageId for SendApplyPassphrase
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SendApplyPassphrasewhere
Option<String>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SendApplyPassphrasewhere
Option<String>: Serialize<__S>,